@@ -4,7 +4,7 @@ test_that("functions return tibbles", {
   # Load some pivoted data
   x <- purpose$`NNW WNW`
   # Make a tidy representation
-  cells <- tidy_table(x)
+  cells <- as_cells(x)
   cells <- cells[!is.na(cells$chr), ]
   # Select the cells containing the values
   data_cells <-
